@@ -534,9 +534,11 @@ def getNodeAttr(node, attr):
         project_name = node.name if node.code == 'Project' else node.getProject().name
 
     obj = db[project_name].find_one({'code': code, '_id': uuid}, {'_id': 0, attr: 1})
+    if not obj:
+        return None
     if attr in obj:
         return obj[attr]
-    return ''
+    return None
 
 
 def createLink(nodeA, nodeB):
